#### R Code for "Exploring the Onset of Phonetic Drift in Perception"

# Load necessary packages:
library(tidyverse)
library(ggplot2)
library(lmerTest)
library(car)
library(emmeans)

### IMPORTING AND FORMATTING DATA

# Import dataset as "HV_data" (HeardVoiceless) data frame (note: prior to this, need to set working directory):
HV_data <- read.table("ExploringOnsetOfDrift_dataset.txt", header=TRUE)

# Recode some variables as factors and set the reference levels:
HV_data$Condition <- as.factor(HV_data$Condition)
HV_data$Participant <- as.factor(HV_data$Participant)
HV_data$Recency <- factor(HV_data$Recency, levels=c("pre-test", "post-test"))
HV_data$Place <- factor(HV_data$Place, levels=c("bilabial", "velar"))

# Add column to differentiate ExposureType:
HV_data$ExposureType <- ifelse(HV_data$Condition == "4", "Ocean", "Tagalog")
# Set reference levels:
HV_data$ExposureType <- factor(HV_data$ExposureType, levels=c("Tagalog", "Ocean"))

# Find and exclude invalid response times (RTs) >9500 ms and outlier RTs >2.5 SDs from participant's mean RT
n <- length(HV_data$ResponseTime) # define number of rows/cells to loop through
# put unfiltered columns of identification responses and RTs into new columns
HV_data$RTRaw <- HV_data$ResponseTime
HV_data$HVRaw <- HV_data$HeardVoiceless
# define a new column coding whether the RT was >9500 ms, meaning the response was invalid (b/c occurred more than 10 sec after stimulus onset)
HV_data$Invalid <- array(dim=n) # will code as invalid, responses for RTs >9500
# first exclude invalid responses
for(i in 1:n) {
	if ((!is.na(HV_data$ResponseTime[i])) & (HV_data$ResponseTime[i] > 9550)) {
		HV_data$HeardVoiceless[i] <- NA
		HV_data$ResponseTime[i] <- NA
		HV_data$Invalid[i] <- 1
		}
	else {
		HV_data$Invalid[i] <- 0	}
}
# then exclude outlier RTs (by participant, for the purposes of later RT inspection)
for(i in 1:n) {
	currsubj <- HV_data$Participant[i]
	currrts <- HV_data$ResponseTime[HV_data$Participant==currsubj]
	currlow <- mean(currrts, na.rm=T) - (2.5 * sd(currrts, na.rm=T))
	currhigh <- mean(currrts, na.rm=T) + (2.5 * sd(currrts, na.rm=T))
	if(!is.na(HV_data$ResponseTime[i]) & HV_data$ResponseTime[i] >= currlow & HV_data$ResponseTime[i] <= currhigh) {
		HV_data$ResponseTime[i] <- HV_data$ResponseTime[i] } 
	else {
		HV_data$ResponseTime[i] <- NA } 
}

# Add a column of log-transformed RTs
HV_data$LogRT <- log10(HV_data$ResponseTime)

# Check whether time/exposure has effect on likelihood of invalid responses using Kruskal-Wallis (non-parametric) ANOVA and logistic model:
kruskal.test(Invalid ~ Exposure, data=HV_data)
# No significant effect of exposure.
inv.glm <- glmer(Invalid ~ Exposure + (1+Exposure|Participant), data=HV_data, family='binomial') # including random effects
summary(inv.glm)
# No significant effect of exposure.

# Check whether participant ages are significantly different between conditions:
age_data <- read.table("ExploringOnsetOfDrift_ages_data.txt", header=TRUE)
age_data$Condition <- factor(age_data$Condition, levels=c("1", "2", "3", "4"))
age_dif <- aov(Age ~ Condition, data=age_data)
summary(age_dif)
# No significant difference between conditions.

# Subset out valid responses only:
HV_data_v <- filter(HV_data, Invalid==0) # valid responses only

# Subset data into each condition:
Condition1 <- filter(HV_data_v, Condition=="1")
Condition2 <- filter(HV_data_v, Condition=="2")
Condition3 <- filter(HV_data_v, Condition=="3")
Condition4 <- filter(HV_data_v, Condition=="4")


### VISUALIZATIONS

## Response time plot (exploratory; not included in paper):
# Exposure as numeric:
HV_data$Exposure <- as.numeric(HV_data$Exposure)
# Set levels of ExposureType:
HV_data$ExposureType <- factor(HV_data$ExposureType, levels=c("Tagalog", "Ocean"))
# Calculate standard error:
HV_data_mean <- aggregate(HV_data$LogRT, list(HV_data$Exposure, HV_data$ExposureType), mean, na.rm=TRUE)
HV_data_se <- aggregate(HV_data$LogRT, list(HV_data$Exposure, HV_data$ExposureType), function(x) sd(x, na.rm=TRUE)/sqrt(length(x)))
HV_data_meanG <- cbind(HV_data_mean, HV_data_se$x)
colnames(HV_data_meanG) <- c("Exposure", "ExposureType", "LogRT", "se")
# Graph:
HV_data_agg <- aggregate(LogRT ~ Exposure + ExposureType + se, FUN=mean, data=HV_data_meanG)
# Print plot:
ggplot(HV_data_agg, aes(x=Exposure, y=LogRT, color=ExposureType, shape=ExposureType)) + 
  geom_line(linewidth=.5, position=position_dodge(0.2)) + 
  geom_point(size=3, position=position_dodge(0.2)) + 
  geom_errorbar(aes(ymin=LogRT-se, ymax=LogRT+se), width=0.2, position=position_dodge(0.2)) +
  theme_minimal() + 
  scale_x_continuous(breaks=scales::pretty_breaks(n=10)) + 
  scale_y_continuous(breaks=scales::pretty_breaks(n=10)) +
  theme(axis.text.x = element_text(size=12)) + theme(axis.text.y = element_text(size=12)) + theme(axis.title.x = element_text(size=15)) + theme(axis.title.y = element_text(size=15)) +
  ylab("Log RT") + xlab("Number of audio exposures elapsed") + 
  scale_shape_manual(name="Exposure Type", labels = c("Tagalog exposure", "Ocean audio exposure"), values=c(2, 16)) + 
  scale_linetype_manual(name="Exposure Type", labels = c("Tagalog exposure", "Ocean audio exposure"), values=c(1, 3)) + 
  scale_color_manual(name="Exposure Type", labels = c("Tagalog exposure", "Ocean audio exposure"), values=c("blue", "black")) +
  theme(legend.position=c(0.5, 0.80)) + theme(legend.title=element_text(face="bold")) + theme(legend.text=element_text(size=11)) + 
  theme(legend.background=element_rect(fill="white", size=0.5, linetype="solid", color="red"))
  
## Change in DV across the exposure period (Figure 8; scatterplot of individual data points):
# Subset dataframe into the FL exposure conditions:
Cond123 <- filter(HV_data, Condition!="4" & Invalid==0) # Conditions 1-3, valid responses only
Cond123.m <- aggregate(HV_data$HeardVoiceless, list(HV_data$Participant, HV_data$Condition, HV_data$Exposure, HV_data$Recency, HV_data$Place), mean, na.rm=TRUE) # average over continuum steps
colnames(Cond123.m) <- c("Participant", "Condition", "Exposure", "Recency", "Place", "HeardVoiceless")
# Print plot:
ggplot(Cond123.m, aes(Exposure, HeardVoiceless, shape=Recency, color=Place)) + theme_minimal() + geom_jitter(position=position_jitter(0.3,0.05)) + 
  scale_y_continuous(breaks=scales::pretty_breaks(n=10), labels=scales::percent, limits=c(0.2,1.0)) + scale_x_continuous(breaks = scales::pretty_breaks(n=10)) + geom_hline(yintercept=0.5, size=.6, linetype="dashed") +
  theme(axis.text.x = element_text(size=12), axis.text.y = element_text(size=12), axis.title.x = element_text(size=12), axis.title.y = element_text(size=12)) + ylab("Likelihood of voiceless judgment (%)") + xlab("Number of FL exposures elapsed") +
  scale_color_manual(name="Place", values=c("#000000", "#0000FF"), labels=c("bilabial", "velar")) + scale_shape_manual(name="Recency", values=c(1, 17), labels=c("less recent exposure", "more recent exposure")) + 
  theme(legend.position=c(0.475, 0.9)) + 
  theme(legend.title=element_text(face="bold")) + theme(legend.text=element_text(size=10)) + theme(legend.key.size = unit(.3, "cm")) +
  theme(legend.box="horizontal")

## Perceptual drift by condition (Figure 9):
# Exposure as numeric:
HV_data_v$Exposure <- as.numeric(HV_data_v$Exposure)
# Levels:
HV_data_v$Condition <- factor(HV_data_v$Condition, levels=c("1", "2", "3", "4"))
# Standard error:
HV_data_mean <- aggregate(HV_data_v$HeardVoiceless, list(HV_data_v$Condition, HV_data_v$Exposure), mean, na.rm=TRUE)
HV_data_se <- aggregate(HV_data_v$HeardVoiceless, list(HV_data_v$Condition, HV_data_v$Exposure), function(x) sd(x, na.rm=TRUE)/sqrt(length(x)))
HV_data_meanG <- cbind(HV_data_mean, HV_data_se$x)
colnames(HV_data_meanG) <- c("Condition", "Exposure", "HeardVoiceless", "se")
# Graph:
HV_data_agg <- aggregate(HeardVoiceless ~ Exposure + Condition + se, FUN=mean, data=HV_data_meanG)
# Print plot:
ggplot(HV_data_agg, aes(x=Exposure, y=HeardVoiceless, color=Condition, shape=Condition)) +
  geom_line(size=.5, position=position_dodge(0.3)) + 
  geom_point(size=3, position=position_dodge(0.3)) + 
  geom_errorbar(aes(ymin=HeardVoiceless-se, ymax=HeardVoiceless+se), width=0.2, position=position_dodge(0.3)) + 
  geom_hline(yintercept=0.5, size=.6, linetype="dashed") +
  theme_minimal() + 
  scale_x_continuous(breaks=scales::pretty_breaks(n=10)) + 
  scale_y_continuous(breaks=scales::pretty_breaks(n=10), labels=scales::percent, limits=c(0.50,0.72)) + 
  theme(axis.text.x = element_text(size=12)) + theme(axis.text.y = element_text(size=12)) + theme(axis.title.x = element_text(size=12)) + theme(axis.title.y = element_text(size=12)) + 
  ylab("Likelihood of voiceless judgment (%)") + xlab("Number of audio exposures elapsed") + 
  scale_color_manual(name="Condition", labels = c("1 (crosslinguistic mapping)", "2 (emotion identification)", "3 (unrelated task)", "4 (active control)"), values = c("red", "#009900", "blue", "black")) + 
  scale_shape_manual(name= "Condition", labels = c("1 (crosslinguistic mapping)", "2 (emotion identification)", "3 (unrelated task)", "4 (active control)"), values=c(1, 17, 2, 16)) + 
  theme(legend.position=c(0.75, 0.85)) + 
  theme(legend.title=element_text(face="bold")) + theme(legend.text=element_text(size=11)) + theme(legend.key.size = unit(.4, "cm"))

## Generalizability of drift (place effects), by condition (Figure 10):
# Exposure as numeric:
HV_data_v$Exposure <- as.numeric(HV_data_v$Exposure)
# Standard error:
HV_data_mean <- aggregate(HV_data_v$HeardVoiceless, list(HV_data_v$Exposure, HV_data_v$ExposureType, HV_data_v$Place, HV_data_v$Condition), mean, na.rm=TRUE)
HV_data_se <- aggregate(HV_data_v$HeardVoiceless, list(HV_data_v$Exposure, HV_data_v$ExposureType, HV_data_v$Place, HV_data_v$Condition), function(x) sd(x, na.rm=TRUE)/sqrt(length(x)))
HV_data_meanG <- cbind(HV_data_mean, HV_data_se$x)
colnames(HV_data_meanG) <- c("Exposure", "ExposureType", "Place", "Condition", "HeardVoiceless", "se")
# Graph:
HV_data_agg <- aggregate(HeardVoiceless ~ Exposure + ExposureType + Place + Condition + se, FUN=mean, data=HV_data_meanG)
HV_data_agg$Condition <- factor(HV_data_agg$Condition, levels=c("1","2","3","4"), labels=c("Condition 1: crosslinguistic mapping","Condition 2: emotion identification","Condition 3: unrelated task","Condition 4: control"))
# Print plot:
ggplot(HV_data_agg, aes(x=Exposure, y=HeardVoiceless, color=Place, shape=Place)) + 
  geom_line(size=.5, position=position_dodge(0.3)) + 
  geom_point(size=3, position=position_dodge(0.3)) + 
  geom_errorbar(aes(ymin=HeardVoiceless-se, ymax=HeardVoiceless+se), width=0.2, position=position_dodge(0.3)) + 
  theme_minimal() + 
  scale_x_continuous(breaks=scales::pretty_breaks(n=10)) + 
  scale_y_continuous(breaks=scales::pretty_breaks(n=10), labels=scales::percent, limits=c(0.47,0.71)) + 
  theme(axis.text.x = element_text(size=12)) + theme(axis.text.y = element_text(size=12)) + theme(axis.title.x = element_text(size=12)) + theme(axis.title.y = element_text(size=12)) + 
  ylab("Likelihood of voiceless judgment (%)") + xlab("Number of audio exposures elapsed") + 
  scale_color_manual(name="Plosive Place", labels = c("bilabial (present in FL exposure)", "velar (absent from FL exposure)"), values=c("blue", "black")) + 
  scale_shape_manual(name= "Plosive Place", labels = c("bilabial (present in FL exposure)", "velar (absent from FL exposure)"), values=c(1, 17)) + 
  theme(legend.position = c(0.875, 0.95)) + theme(legend.title=element_text(face="bold")) + theme(legend.text=element_text(size=11)) + theme(legend.key.size = unit(.4, "cm")) + 
  facet_wrap(~ Condition)

## Recency effects, by condition (Figure 11; exposures 1-9 only)
HV_data_v_1to9 <- filter(HV_data_v, Exposure!=0 & Exposure!=10)
# Exposure as numeric:
HV_data_v_1to9$Exposure <- as.numeric(HV_data_v_1to9$Exposure)
# Standard error:
HV_data_mean <- aggregate(HV_data_v_1to9$HeardVoiceless, list(HV_data_v_1to9$Exposure, HV_data_v_1to9$ExposureType, HV_data_v_1to9$Recency, HV_data_v_1to9$Condition), mean, na.rm=TRUE)
HV_data_se <- aggregate(HV_data_v_1to9$HeardVoiceless, list(HV_data_v_1to9$Exposure, HV_data_v_1to9$ExposureType, HV_data_v_1to9$Recency, HV_data_v_1to9$Condition), function(x) sd(x, na.rm=TRUE)/sqrt(length(x)))
HV_data_meanG <- cbind(HV_data_mean, HV_data_se$x)
colnames(HV_data_meanG) <- c("Exposure", "ExposureType", "Recency", "Condition", "HeardVoiceless", "se")
# Graph:
HV_data_agg <- aggregate(HeardVoiceless ~ Exposure + ExposureType + Recency + Condition + se, FUN=mean, data=HV_data_meanG)
# Relabel condition names
HV_data_agg$Condition <- factor(HV_data_agg$Condition, levels=c("1","2","3","4"), labels=c("Condition 1: crosslinguistic mapping","Condition 2: emotion identification","Condition 3: unrelated task","Condition 4: control"))
# Print plot:
ggplot(HV_data_agg, aes(x=Exposure, y=HeardVoiceless, color=Recency, shape=Recency)) + 
  geom_line(linewidth=.5, position=position_dodge(0.3)) + 
  geom_point(size=3, position=position_dodge(0.3)) + 
  geom_errorbar(aes(ymin=HeardVoiceless-se, ymax=HeardVoiceless+se), width=0.2, position=position_dodge(0.3)) + 
  theme_minimal() + 
  scale_x_continuous(breaks=scales::pretty_breaks(n=10)) + 
  scale_y_continuous(breaks=scales::pretty_breaks(n=10), labels=scales::percent, limits=c(0.52,0.68)) + 
  theme(axis.text.x = element_text(size=12)) + theme(axis.text.y = element_text(size=12)) + theme(axis.title.x = element_text(size=12)) + theme(axis.title.y = element_text(size=12)) + 
  ylab("Likelihood of voiceless judgment (%)") + xlab("Number of audio exposures elapsed") + 
  scale_color_manual(name="Recency", labels = c("pre-test / less recent exposure", "post-test / more recent exposure"), values=c("blue", "black")) + 
  scale_shape_manual(name= "Recency", labels = c("pre-test / less recent exposure", "post-test / more recent exposure"), values=c(1, 17)) + 
  theme(legend.position = c(0.85, 0.92)) + 
  theme(legend.title=element_text(face="bold")) + theme(legend.text=element_text(size=11)) + theme(legend.key.size = unit(.4, "cm")) + 
  facet_wrap(~ Condition)

## Graphs of participant trends (in supplementary materials)

# Participant trends for Condition 4 (Figure A4):
Cond4_graph <- aggregate(HeardVoiceless ~ Exposure + Participant, FUN=mean, data=Condition4)
# Print plot:
ggplot(Cond4_graph, aes(x=Exposure, y=HeardVoiceless, color=Participant, shape=Participant)) + 
  geom_line() + 
  geom_point(size=3) + 
  theme_minimal() + 
  scale_x_continuous(breaks = scales::pretty_breaks(n=10)) +
  scale_y_continuous(breaks=scales::pretty_breaks(n=10), labels=scales::percent, limits=c(0.3,0.80)) + 
  theme(axis.text.x = element_text(size=12)) + theme(axis.text.y = element_text(size=12)) + theme(axis.title.x = element_text(size=15)) + theme(axis.title.y = element_text(size=15)) + ylab("Likelihood of voiceless judgment (%)") + xlab("Number of ocean exposures elapsed") + 
  theme(legend.title=element_text(face="bold")) + 
  scale_shape_manual(name = "Participant", values=c(0, 5, 10, 15, 1, 6, 11, 2, 7, 12, 17, 3, 8, 18, 9, 14, 19)) +
  scale_color_manual(name = "Participant", values=c("#FF0000", "#FF9933", "#CC6600", "#CCCC00", "#33CC00", "#006600", "#339966", "#00CCCC", "#33CCFF", "#3399FF", "#330099", "#9900CC", "#660066", "#FF3399", "#FF33CC", "#666666", "#000000")) +
  ggtitle(label="Condition 4 (active control)") + theme(plot.title = element_text(hjust = 0.5)) + theme(plot.title = element_text(size = 15, face = "plain"))

# Participant trends for Condition 1 (Figure A1):
Cond1_graph <- aggregate(HeardVoiceless ~ Exposure + Participant, FUN = mean, data=Condition1)
# Print plot:
ggplot(Cond1_graph, aes(x=Exposure, y=HeardVoiceless, color=Participant, shape=Participant)) +
  geom_line() + 
  geom_point(size=3) + 
  theme_minimal() + 
  scale_x_continuous(breaks = scales::pretty_breaks(n=10)) +
  scale_y_continuous(breaks=scales::pretty_breaks(n=10), labels=scales::percent, limits=c(0.4,0.80)) + 
  theme(axis.text.x = element_text(size=12)) + theme(axis.text.y = element_text(size=12)) + theme(axis.title.x = element_text(size=15)) + theme(axis.title.y = element_text(size=15)) + ylab("Likelihood of voiceless judgment (%)") + xlab("Number of Tagalog exposures elapsed") + 
  theme(legend.title=element_text(face="bold")) + 
  scale_shape_manual(name = "Participant", values=c(0, 5, 10, 15, 6, 2, 7, 12, 17, 3, 8, 18, 9, 14, 19)) +
  scale_color_manual(name = "Participant", values=c("#FF0000", "#FF9933", "#CC6600", "#CCCC00", "#33CC00", "#006600", "#339966", "#33CCFF", "#3399FF", "#330099", "#9900CC", "#660066", "#FF33CC", "#666666", "#000000")) +
  ggtitle(label="Condition 1 (crosslinguistic mapping)") + theme(plot.title = element_text(hjust = 0.5)) + theme(plot.title = element_text(size = 15, face = "plain"))

# Participant trends for Condition 2 (Figure A2):
Cond2_graph <- aggregate(HeardVoiceless ~ Exposure + Participant, FUN = mean, data=Condition2)
# Print plot:
ggplot(Cond2_graph, aes(x=Exposure, y=HeardVoiceless, color=Participant, shape=Participant)) + 
  geom_line() + 
  geom_point(size=3) + 
  theme_minimal() + 
  scale_x_continuous(breaks = scales::pretty_breaks(n=10)) +
  scale_y_continuous(breaks=scales::pretty_breaks(n=10), labels=scales::percent, limits=c(0.35,0.80)) + 
  theme(axis.text.x = element_text(size=12)) + theme(axis.text.y = element_text(size=12)) + theme(axis.title.x = element_text(size=15)) + theme(axis.title.y = element_text(size=15)) + ylab("Likelihood of voiceless judgment (%)") + xlab("Number of Tagalog exposures elapsed") + 
  theme(legend.title=element_text(face="bold")) + 
  scale_shape_manual(name = "Participant", values=c(0, 5, 10, 15, 6, 12, 17, 3, 9, 14, 19)) +
  scale_color_manual(name = "Participant", values=c("#FF0000", "#FF9933", "#CCCC00", "#33CC00", "#006600", "#33CCFF", "#3399FF", "#330099", "#9900CC", "#FF33CC", "#000000")) +
  ggtitle(label="Condition 2 (emotion identification)") + theme(plot.title = element_text(hjust = 0.5)) + theme(plot.title = element_text(size = 15, face = "plain"))

# Participant trends for Condition 3 (Figure A3):
Cond3_graph <- aggregate(HeardVoiceless ~ Exposure + Participant, FUN = mean, data=Condition3)
# Print plot:
ggplot(Cond3_graph, aes(x=Exposure, y=HeardVoiceless, color=Participant, shape=Participant)) + 
  geom_line() + 
  geom_point(size=3) + 
  theme_minimal() + 
  scale_x_continuous(breaks = scales::pretty_breaks(n=10)) +
  scale_y_continuous(breaks=scales::pretty_breaks(n=10), labels=scales::percent, limits=c(0.4,0.80)) + 
  theme(axis.text.x = element_text(size=12)) + theme(axis.text.y = element_text(size=12)) + theme(axis.title.x = element_text(size=15)) + theme(axis.title.y = element_text(size=15)) + ylab("Likelihood of voiceless judgment (%)") + xlab("Number of Tagalog exposures elapsed") + 
  theme(legend.title=element_text(face="bold")) + 
  scale_shape_manual(name = "Participant", values=c(0, 10, 15, 6, 12, 17, 9, 14, 19)) +
  scale_color_manual(name = "Participant", values=c("#FF0000", "#FF9933", "#CCCC00", "#33CC00", "#33CCFF", "#3399FF", "#9900CC", "#FF33CC", "#000000")) +
  ggtitle(label="Condition 3 (unrelated task)") + theme(plot.title = element_text(hjust = 0.5)) + theme(plot.title = element_text(size = 15, face = "plain"))


### STATISTICAL ANALYSIS

## MODEL 1 (testing hypotheses H1-H3, H5)

# Ensure that Exposure is coded as numeric:
HV_data_v$Exposure <- as.numeric(HV_data_v$Exposure)
# Add centered Exposure predictor:
HV_data_v$ExposureC <- HV_data_v$Exposure - mean(HV_data_v$Exposure, na.rm=TRUE)

# Condition 4 as the reference level:
HV_data_v$Condition <- factor(HV_data_v$Condition, levels=c("4", "1", "2", "3"))
model1d <- glmer(HeardVoiceless ~ ExposureC*Condition*Place + (1|Participant), data=HV_data_v, family='binomial')
Anova(model1d) # inspect main effects and interactions
summary(model1d) # retrieve coefficients
# see if including random slopes for Exposure by Participant changes anything
model1ds <- glmer(HeardVoiceless ~ ExposureC*Condition*Place + (1 + Exposure|Participant), data=HV_data_v, family='binomial')
Anova(model1ds) # inspect main effects and interactions - no difference in overall pattern of results
summary(model1ds) # retrieve coefficients - no difference in overall pattern of results

# Condition 1 as the reference level:
HV_data_v$Condition <- factor(HV_data_v$Condition, levels=c("1", "2", "3", "4"))
model1a <- glmer(HeardVoiceless ~ ExposureC*Condition*Place + (1|Participant), HV_data_v, family="binomial")
summary(model1a)

# Condition 2 as the reference level:
HV_data_v$Condition <- factor(HV_data_v$Condition, levels=c("2", "1", "3", "4"))
model1b <- glmer(HeardVoiceless ~ ExposureC*Condition*Place + (1|Participant), HV_data_v, family="binomial")
summary(model1b)

# Condition 3 as the reference level:
HV_data_v$Condition <- factor(HV_data_v$Condition, levels=c("3", "1", "2", "4"))
model1c <- glmer(HeardVoiceless ~ ExposureC*Condition*Place + (1|Participant), HV_data_v, family="binomial")
summary(model1c)

## MODEL 2 (testing hypothesis H4)

# Subset out data for exposures 1-9 only
HV_data_v_1to9 <- filter(HV_data_v, Exposure!=0 & Exposure!=10)
# Exposure as numeric:
HV_data_v_1to9$Exposure <- as.numeric(HV_data_v_1to9$Exposure)
# Add (re)centered Exposure predictor:
HV_data_v_1to9$ExposureC <- HV_data_v_1to9$Exposure - mean(HV_data_v_1to9$Exposure, na.rm=TRUE)

# Condition 4 as the reference level:
HV_data_v_1to9$Condition <- factor(HV_data_v_1to9$Condition, levels=c("4", "1", "2", "3"))
model2d <- glmer(HeardVoiceless ~ ExposureC*Condition*Recency + (1|Participant), HV_data_v_1to9, family="binomial")
Anova(model2d) # inspect main effects and interactions
summary(model2d) # retrieve coefficients
# see if including random slopes for Exposure by Participant changes anything
model2ds <- glmer(HeardVoiceless ~ ExposureC*Condition*Recency + (1 + Exposure|Participant), data=HV_data_v_1to9, family='binomial')
Anova(model2ds) # inspect main effects and interactions - no difference in overall pattern of results
summary(model2ds) # retrieve coefficients - no difference in overall pattern of results

# Condition 1 as the reference level:
HV_data_v_1to9$Condition <- factor(HV_data_v_1to9$Condition, levels=c("1", "2", "3", "4"))
model2a <- glmer(HeardVoiceless ~ ExposureC*Condition*Recency + (1|Participant), HV_data_v_1to9, family="binomial")
summary(model2a)

# Condition 2 as the reference level:
HV_data_v_1to9$Condition <- factor(HV_data_v_1to9$Condition, levels=c("2", "1", "3", "4"))
model2b <- glmer(HeardVoiceless ~ ExposureC*Condition*Recency + (1|Participant), HV_data_v_1to9, family="binomial")
summary(model2b)

# Condition 3 as the reference level:
HV_data_v_1to9$Condition <- factor(HV_data_v_1to9$Condition, levels=c("3", "1", "2", "4"))
model2c <- glmer(HeardVoiceless ~ ExposureC*Condition*Recency + (1|Participant), HV_data_v_1to9, family="binomial")
summary(model2c)

## MODEL 2' (probing hypothesis H4 further)

HV_data_v_1to9$ExposureType <- factor(HV_data_v_1to9$ExposureType, levels=c("Tagalog", "Ocean"), labels=c("1-3", "4"))
model2prime <- glmer(HeardVoiceless ~ ExposureC*ExposureType*Recency + (1|Participant), HV_data_v_1to9, family="binomial")
summary(model2prime)

## MODEL 3 (exploring hypothesis H1 further; onset of perceptual drift)

# Code Exposure as categorical:
HV_data_v$ExposureF <- as.factor(HV_data_v$Exposure)

# Condition 4 as the reference level:
HV_data_v$Condition <- factor(HV_data_v$Condition, levels=c("4", "1", "2", "3"))
model3 <- glmer(HeardVoiceless ~ ExposureF*Condition + (1|Participant), HV_data_v, family="binomial")
summary(model3)

# Inspect pairwise comparisons between later exposures and baseline
emmeans(model3, ~ ExposureF + Condition) %>% contrast("pairwise", by=NULL)
